@@ -1,3 +1,4 @@
+### ch. 1.  Financial Time Series and Their Characteristics
 ###
 ### 
 ### Ruey S. Tsay (2005)
@@ -5,10 +6,6 @@
 ### (Wiley)
 ###
 ### 
-
-###
-### ch. 1.  Financial Time Series and Their Characteristics
-###
 library(FinTS)
 
 ##
@@ -44,7 +41,7 @@ mo.logRtns <- c(.0446, -.0734, .1077)
 # Example 1.2.
 data(d.ibmvwewsp6203)
 s.ibm <- sd(d.ibmvwewsp6203[, "IBM"])
-(skew.ibm <- skewness(d.ibmvwewsp6203[, "IBM"]))
+(skew.ibm <- e1071::skewness(d.ibmvwewsp6203[, "IBM"]))
 (n.ibm <- dim(d.ibmvwewsp6203)[1])
 (skew.sd <- sqrt(6/n.ibm))
 (t.sk <- (skew.ibm/skew.sd))
